==> distribution-6.0.0-dev.128.zip: drr/regulation/common/validation/exists/CommonTransactionInformationOnlyExistsValidator.java <==
package drr.regulation.common.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.CommonTransactionInformation;
import drr.regulation.common.TradableOnTradingVenueEnum;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class CommonTransactionInformationOnlyExistsValidator implements ValidatorWithArg<CommonTransactionInformation, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends CommonTransactionInformation> ValidationResult<CommonTransactionInformation> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("tradableOnTradingVenue", ExistenceChecker.isSet((TradableOnTradingVenueEnum) o.getTradableOnTradingVenue()))
				.put("underlierTradedOnTradingVenue", ExistenceChecker.isSet((Boolean) o.getUnderlierTradedOnTradingVenue()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("CommonTransactionInformation", ValidationType.ONLY_EXISTS, "CommonTransactionInformation", path, "");
		}
		return failure("CommonTransactionInformation", ValidationType.ONLY_EXISTS, "CommonTransactionInformation", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}

==> distribution-6.25.3.zip: drr/regulation/common/validation/exists/CommonTransactionInformationOnlyExistsValidator.java <==
package drr.regulation.common.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.CommonTransactionInformation;
import drr.regulation.common.TradableOnTradingVenueEnum;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class CommonTransactionInformationOnlyExistsValidator implements ValidatorWithArg<CommonTransactionInformation, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends CommonTransactionInformation> ValidationResult<CommonTransactionInformation> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("tradableOnTradingVenue", ExistenceChecker.isSet((TradableOnTradingVenueEnum) o.getTradableOnTradingVenue()))
				.put("underlierTradedOnTradingVenue", ExistenceChecker.isSet((Boolean) o.getUnderlierTradedOnTradingVenue()))
				.put("underlierAssetTradingPlatformIdentifier", ExistenceChecker.isSet((String) o.getUnderlierAssetTradingPlatformIdentifier()))
				.put("internalTradeIdentifier", ExistenceChecker.isSet((String) o.getInternalTradeIdentifier()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("CommonTransactionInformation", ValidationResult.ValidationType.ONLY_EXISTS, "CommonTransactionInformation", path, "");
		}
		return failure("CommonTransactionInformation", ValidationResult.ValidationType.ONLY_EXISTS, "CommonTransactionInformation", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}
